pub struct EnvelopeService<P>where
P: KeyProvider,{ /* private fields */ }Expand description
High-level service responsible for encrypting and decrypting secret records.
Implementations
Sourceimpl<P> EnvelopeService<P>where
P: KeyProvider,
impl<P> EnvelopeService<P>where
P: KeyProvider,
Sourcepub fn new(provider: P, cache: DekCache, algorithm: EncryptionAlgorithm) -> Self
pub fn new(provider: P, cache: DekCache, algorithm: EncryptionAlgorithm) -> Self
Constructs a new service with the supplied components.
Sourcepub fn from_env(provider: P) -> Result<Self>
pub fn from_env(provider: P) -> Result<Self>
Builds a service using environment configuration and default cache parameters.
Sourcepub fn algorithm(&self) -> EncryptionAlgorithm
pub fn algorithm(&self) -> EncryptionAlgorithm
Currently configured algorithm.
Sourcepub fn encrypt_record(
&mut self,
meta: SecretMeta,
plaintext: &[u8],
) -> Result<SecretRecord>
pub fn encrypt_record( &mut self, meta: SecretMeta, plaintext: &[u8], ) -> Result<SecretRecord>
Encrypts plaintext into a SecretRecord using envelope encryption.
Sourcepub fn decrypt_record(
&mut self,
record: &SecretRecord,
) -> DecryptResult<Vec<u8>>
pub fn decrypt_record( &mut self, record: &SecretRecord, ) -> DecryptResult<Vec<u8>>
Decrypts the ciphertext of a SecretRecord.