pub struct Http { /* private fields */ }Expand description
Thin synchronous facade over the async reqwest client.
Implementations
Sourceimpl Http
impl Http
Sourcepub fn new(timeout: Duration) -> Result<Self>
pub fn new(timeout: Duration) -> Result<Self>
Builds a client with the provided timeout and rustls TLS stack.
Sourcepub fn from_builder(builder: ClientBuilder) -> Result<Self>
pub fn from_builder(builder: ClientBuilder) -> Result<Self>
Builds a client from a custom reqwest builder.
Sourcepub fn builder() -> HttpBuilder
pub fn builder() -> HttpBuilder
Starts building an HTTP client with custom provider options.
Sourcepub fn request(&self, method: Method, url: impl AsRef<str>) -> HttpRequest
pub fn request(&self, method: Method, url: impl AsRef<str>) -> HttpRequest
Creates a new request with the provided method and URL.
pub fn get(&self, url: impl AsRef<str>) -> HttpRequest
pub fn post(&self, url: impl AsRef<str>) -> HttpRequest
pub fn put(&self, url: impl AsRef<str>) -> HttpRequest
pub fn delete(&self, url: impl AsRef<str>) -> HttpRequest
pub fn client(&self) -> &Client