pub struct SecretSpecRegistry { /* private fields */ }Expand description
Registry that merges secrets declared by multiple components.
Implementations
Sourceimpl SecretSpecRegistry
impl SecretSpecRegistry
Sourcepub fn extend_with(&mut self, specs: &'static [SecretSpec])
pub fn extend_with(&mut self, specs: &'static [SecretSpec])
Extend the registry with additional specs, deduplicating by name.
Sourcepub fn all(&self) -> impl Iterator<Item = &SecretSpec>
pub fn all(&self) -> impl Iterator<Item = &SecretSpec>
Iterate over all stored specs in deterministic order.
Sourcepub fn to_markdown_table(&self) -> String
pub fn to_markdown_table(&self) -> String
Render the registry to a Markdown table suitable for CLI output.