pub struct SecretsBroker<B, P>where
B: SecretsBackend,
P: KeyProvider,{ /* private fields */ }Expand description
High-level API that pairs a backend with the envelope crypto stack.
Implementations
Sourceimpl<B, P> SecretsBroker<B, P>where
B: SecretsBackend,
P: KeyProvider,
impl<B, P> SecretsBroker<B, P>where
B: SecretsBackend,
P: KeyProvider,
Sourcepub fn new(backend: B, crypto: EnvelopeService<P>) -> Self
pub fn new(backend: B, crypto: EnvelopeService<P>) -> Self
Construct a new broker façade from the provided backend and crypto service.
Sourcepub fn put_secret(
&mut self,
meta: SecretMeta,
data: &[u8],
) -> Result<SecretVersion>
pub fn put_secret( &mut self, meta: SecretMeta, data: &[u8], ) -> Result<SecretVersion>
Encrypt and store a secret, returning the version assigned by the backend.
Sourcepub fn get_secret(
&mut self,
uri: &SecretUri,
) -> DecryptResult<Option<BrokerSecret>>
pub fn get_secret( &mut self, uri: &SecretUri, ) -> DecryptResult<Option<BrokerSecret>>
Retrieve and decrypt the latest revision of a secret.
Sourcepub fn get_secret_version(
&mut self,
uri: &SecretUri,
version: Option<u64>,
) -> DecryptResult<Option<BrokerSecret>>
pub fn get_secret_version( &mut self, uri: &SecretUri, version: Option<u64>, ) -> DecryptResult<Option<BrokerSecret>>
Retrieve and decrypt a specific revision of a secret.
Sourcepub fn list_secrets(
&self,
scope: &Scope,
category_prefix: Option<&str>,
name_prefix: Option<&str>,
) -> Result<Vec<SecretListItem>>
pub fn list_secrets( &self, scope: &Scope, category_prefix: Option<&str>, name_prefix: Option<&str>, ) -> Result<Vec<SecretListItem>>
List available secrets for a scope with optional category/name prefixes.
Sourcepub fn delete_secret(&self, uri: &SecretUri) -> Result<SecretVersion>
pub fn delete_secret(&self, uri: &SecretUri) -> Result<SecretVersion>
Soft-delete a secret (tombstone).
Sourcepub fn versions(&self, uri: &SecretUri) -> Result<Vec<SecretVersion>>
pub fn versions(&self, uri: &SecretUri) -> Result<Vec<SecretVersion>>
Fetch all versions known for a secret.
Sourcepub fn exists(&self, uri: &SecretUri) -> Result<bool>
pub fn exists(&self, uri: &SecretUri) -> Result<bool>
Determine whether the latest revision of the secret exists.
Sourcepub fn crypto(&self) -> &EnvelopeService<P>
pub fn crypto(&self) -> &EnvelopeService<P>
Borrow the envelope service for custom workflows.
Sourcepub fn crypto_mut(&mut self) -> &mut EnvelopeService<P>
pub fn crypto_mut(&mut self) -> &mut EnvelopeService<P>
Mutable access to the envelope service (mainly for tests).